summaryrefslogtreecommitdiffstats
path: root/transform/chain.go
diff options
context:
space:
mode:
authorbep <bjorn.erik.pedersen@gmail.com>2015-03-19 01:55:49 +0100
committerbep <bjorn.erik.pedersen@gmail.com>2015-03-19 02:07:57 +0100
commit66cf3bdc77d43f92333cd48a351d59d7a5abe1f8 (patch)
tree395f711d96b4528e4da842ff4da8f92a245bfc94 /transform/chain.go
parentefb564775afd319b953a386cf9e8cc1aca0b585e (diff)
Rename interface contentRewriter to contentTransformer
Is is a much better name.
Diffstat (limited to 'transform/chain.go')
-rw-r--r--transform/chain.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/transform/chain.go b/transform/chain.go
index a42660245..6c41c4199 100644
--- a/transform/chain.go
+++ b/transform/chain.go
@@ -6,7 +6,7 @@ import (
"io"
)
-type trans func(rw contentRewriter)
+type trans func(rw contentTransformer)
type link trans
@@ -20,14 +20,14 @@ func NewEmptyTransforms() []link {
return make([]link, 0, 20)
}
// contentRewriter is an interface that enables rotation
// of pooled buffers in the transformer chain.
-type contentRewriter interface {
+type contentTransformer interface {
Content() []byte
io.Writer
}
-// Implements contentRewriter
+// Implements contentTransformer
// Content is read from the from-buffer,
// and rewritten to to the to-buffer.
type fromToBuffer struct {
@@ -20,14 +20,14 @@ func NewEmptyTransforms() []link {
return make([]link, 0, 20)
}
-// contentRewriter is an interface that enables rotation
+// contentTransformer is an interface that enables rotation
// of pooled buffers in the transformer chain.